@@ -113,6 +113,9 @@
 #define RE_POSITIVE     (RE_MODERROR + 10) /* Positive number expected */
 #define RE_NAMETOOLONG  (RE_MODERROR + 11) /* Variable name too long */
 #define RE_UNBALPAR     (RE_MODERROR + 12) /* Unbalanced parentheses */
+#define RE_NOOUTPUTEQN  (RE_MODERROR + 13) /* Missing dyn eqn for szMsg */
+#define RE_DUPSECT      (RE_MODERROR + 14) /* Duplicated section szMsg */
+#define RE_NOEND        (RE_MODERROR + 15) /* Missing End keyword */
 
 #define RE_SIMERROR     0x0200 /* Simulation error prefix */
 
