@@ -968,11 +968,10 @@ void ReversePointers (PVMMAPSTRCT *ppvm)
 
    Uses info pointer of ForAllVar's callback as a second eqn list.
 
-   (1) If the list is second list is NULL, checks for initialization
+   (1) If the second list is NULL, checks for initialization
    of pvm.
 
-   (2) If the list in non-NULL, checks the second-list for
-   definition.
+   (2) If the second list in non-NULL, checks it for definition.
 
    Note that case (1) and (2) apply to inputs and dynamics eqns respectively.
    Further assertion will have to be handled otherwise.  Parms are
@@ -1004,6 +1003,13 @@ int AssertExistsEqn (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 
 
 /* ----------------------------------------------------------------------------
+   VerifyEqns
+
+   Check that each state variable has an associated differential equation
+   defined.
+
+   Calls AssertExistsEqn on each and return a fatal error if one or more
+   equation is missing.
 */
 void VerifyEqns (PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmDyn)
 {
@@ -1013,11 +1019,66 @@ void VerifyEqns (PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmDyn)
                                       ID_STATE, (PVOID) pvmDyn));
 
   if (!bStatesOK)
-    ReportError (NULL, RE_FATAL, NULL, "State equations missing");
+    ReportError (NULL, RE_FATAL, NULL, "State equations missing.\n");
 
 } /* VerifyEqns */
 
 
+/* ----------------------------------------------------------------------------
+   AssertExistsOutputEqn
+
+   Check that an equation exists in either the Dynamics section or the
+   CalcOutputs section for each output variable.
+
+   The errors are not reported as fatal so that all errors can
+   be discovered.  They will cause exit subsequently.
+*/
+int AssertExistsOutputEqn (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
+{
+  int iReturn = 0;
+  PINPUTINFO  pinfo = (PINPUTINFO) pInfo;
+  PVMMAPSTRCT pvmDyn = (PVMMAPSTRCT) pinfo->pvmDynEqns;
+  PVMMAPSTRCT pvmOut = (PVMMAPSTRCT) pinfo->pvmCalcOutEqns;
+
+  if (pvm->szEqn != vszHasInitializer) { /* Don't count these! */
+
+    if ((GetVarPTR (pvmDyn, pvm->szName) == NULL) &&
+        (GetVarPTR (pvmOut, pvm->szName) == NULL)) {
+      ReportError (NULL, RE_NOOUTPUTEQN, pvm->szName, NULL);
+      iReturn = 0;
+    }
+    else
+      iReturn = 1;
+  } /* if */
+
+  /* If HasInitializer, no error to report */
+  return (iReturn ? 1 : 0);
+
+} /* AssertExistsOutputEqn */
+
+
+/* ----------------------------------------------------------------------------
+   VerifyOutputEqns
+
+   Check that each output variable has an associated equation defined.
+
+   Calls AssertExistsOutputEqn on each and return a fatal error if one or more
+   equation is missing.
+*/
+void VerifyOutputEqns (PINPUTINFO pInfo)
+{
+  BOOL bOutputsOK;
+
+  bOutputsOK = (vnOutputs == ForAllVar (NULL, pInfo->pvmGloVars, 
+                                        &AssertExistsOutputEqn, ID_OUTPUT,
+                                        (PVOID) pInfo));
+
+  if (!bOutputsOK)
+    ReportError (NULL, RE_FATAL, NULL, "Output equations missing.\n");
+
+} /* VerifyOutputEqns */
+
+
 /* ----------------------------------------------------------------------------
    WriteModel
 
@@ -1044,6 +1105,8 @@ void WriteModel (PINPUTINFO pinfo, PSTR szFileOut)
   AdjustVarHandles (pinfo->pvmGloVars);
   VerifyEqns (pinfo->pvmGloVars, pinfo->pvmDynEqns);
 
+  VerifyOutputEqns (pinfo);
+
   pfile = fopen (szFileOut, "w");
   if (pfile) {
 
@@ -1054,9 +1117,9 @@ void WriteModel (PINPUTINFO pinfo, PSTR szFileOut)
     WriteHeader (pfile, szFileOut, pinfo->pvmGloVars);
 
     WriteIncludes (pfile);
-    WriteDecls   (pfile, pinfo->pvmGloVars);
-    WritebDelays (pfile, pinfo->bDelays);
-    WriteVarMap  (pfile, pinfo->pvmGloVars);
+    WriteDecls    (pfile, pinfo->pvmGloVars);
+    WritebDelays  (pfile, pinfo->bDelays);
+    WriteVarMap   (pfile, pinfo->pvmGloVars);
 
     WriteInitModel   (pfile, pinfo->pvmGloVars);
     WriteCalcDeriv   (pfile, pinfo->pvmGloVars, pinfo->pvmDynEqns);
@@ -1574,6 +1637,8 @@ void Write_R_Model (PINPUTINFO pinfo, PSTR szFileOut)
   AdjustVarHandles (pinfo->pvmGloVars);
   VerifyEqns (pinfo->pvmGloVars, pinfo->pvmDynEqns);
 
+  VerifyOutputEqns (pinfo);
+
   pfile = fopen (szFileOut, "w");
   if (pfile) {
 
