@@ -106,7 +106,7 @@ void ReportError (PINPUTBUF pibIn, WORD wCode, PSTR szMsg, PSTR szAltMsg)
     break;
 
   case RE_READERROR:
-    printf ("Input files cannot be read\n");
+    printf ("%s file cannot be read\n", szMsg);
     break;
 
   case RE_UNEXPECTED:
