@@ -48,6 +48,7 @@
 #include "lexfn.h"
 #include "matutil.h"
 #include "modelu.h"
+#include "simi.h"
 #include "strutil.h"
 #include "modiface.h"
 
@@ -432,7 +433,6 @@ BOOL GetEvents (PINPUTBUF pibIn, PSTR szLex, PIFN pifn)
     bOK &= DefDepParm (rgszLex[i], pifn->rgT0s+i, pifn->rghT0s+i);
 
   /* operations */
-  int ikwcode;
   for (i = 0; i < pifn->nDoses; i++) {
     pifn->rgOper[i] = GetKeywordCode (rgszLex[pifn->nDoses + i], NULL);
     if (!(pifn->rgOper[i])) 
