@@ -1939,6 +1939,7 @@ int RunExpt (PLEVEL plevel, char **args)
 
 } /* RunExpt */
 
+
 /* Function -------------------------------------------------------------------
    SampleTemperature
 */
@@ -1972,9 +1973,8 @@ long SampleTemperature (PGIBBSDATA pgd, double dLnPrior, double dLnData)
 
 
 /* Function -------------------------------------------------------------------
-   SampleTheta
+   SampleTheta, samples from a normal kernel
 */
-
 double SampleTheta (PMCVAR pMCVar) {
 
   /* if the parameter has a discrete distribution, round it - FB 12/06/97 */
@@ -1991,6 +1991,20 @@ double SampleTheta (PMCVAR pMCVar) {
 } /* SampleTheta */
 
 
+/* Function -------------------------------------------------------------------
+   SampleThetaUnif, samples from a uniform kernel
+*/
+double SampleThetaUnif (PMCVAR pMCVar) {
+
+  /* if the parameter has a discrete distribution, round it */
+  if (pMCVar->iType == MCV_BINOMIAL || pMCVar->iType == MCV_POISSON)
+    return floor (0.5 + UniformRandom (MinMCVar(pMCVar), MaxMCVar(pMCVar)));
+  else
+    return UniformRandom (MinMCVar(pMCVar), MaxMCVar(pMCVar));
+
+} /* SampleThetaUnif */
+
+
 /* Function -------------------------------------------------------------------
    SampleThetas
 
@@ -2286,37 +2300,45 @@ void SampleThetasTempered (PLEVEL plevel, char **args)
 
     /* sample a new value */
 
-    /* first scale temporarily the kernelSD according to the temperature */
+    if (pgd->rgInvTemperatures[*pindexT] > 0) { // usual case
+    
+      /* first scale temporarily the kernelSD according to the temperature */
 
-    /* save the current kernelSD */
-    old_dKernelSD =  pMCVar->dKernelSD;
+      /* save the current kernelSD */
+      old_dKernelSD = pMCVar->dKernelSD;
 
-    /* update the kernelSD according to the temperature, the formula
-       comes from that of the variance of the powered normal */
-    pMCVar->dKernelSD = pow(2 * PI, 
-                            0.5 * (1 - pgd->rgInvTemperatures[*pindexT])) *
-                        pow(pMCVar->dKernelSD, 
-                            3 - pgd->rgInvTemperatures[*pindexT]) /
-                        pow(pgd->rgInvTemperatures[*pindexT], 1.5);
+      /* update the kernelSD according to the temperature, the formula
+         comes from that of the variance of the powered normal */
+      pMCVar->dKernelSD = pow(2 * PI, 
+                              0.5 * (1 - pgd->rgInvTemperatures[*pindexT])) *
+                          pow(pMCVar->dKernelSD, 
+                              3 - pgd->rgInvTemperatures[*pindexT]) /
+                          pow(pgd->rgInvTemperatures[*pindexT], 1.5);
 
-    /* check that kernel SD does not increase wildly */
-    if (pMCVar->dKernelSD > pMCVar->dMaxKernelSD)
-      pMCVar->dKernelSD = pMCVar->dMaxKernelSD;
+      /* check that kernel SD does not increase wildly */
+      if (pMCVar->dKernelSD > pMCVar->dMaxKernelSD)
+        pMCVar->dKernelSD = pMCVar->dMaxKernelSD;
 
-    // Compute density under jump kernel
-    dLnKern  = log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
-                              pMCVar->dKernelSD) -
-                   CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
-                              pMCVar->dKernelSD));
+      // Compute density under jump kernel
+      dLnKern  = log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
+                                pMCVar->dKernelSD) -
+                     CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
+                                pMCVar->dKernelSD));
 
-    /* sample a new value */
-    pMCVar->dVal = SampleTheta (pMCVar);
+      /* sample a new value */
+      pMCVar->dVal = SampleTheta (pMCVar);
 
-    // update density under jump kernel
-    dLnKernNew  =  log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
-                                  pMCVar->dKernelSD) -
-                       CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
-                                  pMCVar->dKernelSD));
+      // update density under jump kernel
+      dLnKernNew  =  log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
+                                    pMCVar->dKernelSD) -
+                         CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
+                                    pMCVar->dKernelSD));
+    } 
+    else { // inverse temperature is zero, sample uniformly
+      dLnKern = dLnKernNew  = 1;
+      // sample a new value uniformly on its range
+      pMCVar->dVal = SampleThetaUnif (pMCVar);
+    }
 
     /* recompute prior and likelihood */
     dLnPriorNew = LnDensity (pMCVar, panal);
@@ -2351,8 +2373,8 @@ void SampleThetasTempered (PLEVEL plevel, char **args)
         TraverseLevels1 (plevel, SaveLikelihoods, NULL);
     }
 
-    /* restore kernelSD */
-    pMCVar->dKernelSD = old_dKernelSD;
+    if (pgd->rgInvTemperatures[*pindexT] > 0) /* restore kernelSD */
+      pMCVar->dKernelSD = old_dKernelSD;
 
 WriteIt: /* Write the MC var value to output file  */
 
