@@ -311,7 +311,9 @@ void UpdateDefaultInput (PIFN pifn, PDOUBLE pdTnext, PDOUBLE pdTime)
 
   if (pifn->bOn) {
     *pdTnext += pifn->dTexp; /* Check second transition of pulse */
-    pifn->bOn = (*pdTime < *pdTnext); /* Time is before pulse goes off */
+    /* if time is reasonably before pulse goes off then pulse is on */
+    pifn->bOn = (*pdTime < *pdTnext) && 
+                ((*pdTnext - *pdTime) > DBL_EPSILON * 2.0 * (*pdTnext));
 
     if (!pifn->bOn) {
       if (pifn->dTper != 0.0) /* Periodic */
