@@ -358,6 +358,7 @@ int Estimate_y (PANALYSIS panal, double *pdTheta, double *pdY)
 void ReadAndSimulate (PANALYSIS panal, long nSetParms, 
                       double **pdY, long nPreds, PMCVAR *pLikes, long nSims)
 {
+  register char c;
   long lDummy, iter = 0;
   long j;
   PDOUBLE pdTheta = NULL;
@@ -381,11 +382,7 @@ void ReadAndSimulate (PANALYSIS panal, long nSetParms,
 
   /* Skip the first line. This allows a MC output file to be used
      directly as a restart file. */
-  if (!fscanf (pfileRestart,  "%*[^\n]")) {
-    ReportError (NULL, RE_READERROR | RE_FATAL, panal->gd.szGrestart, NULL);
-  }
-  else
-    getc(pfileRestart);
+  do { c = getc(pfileRestart); } while (c != '\n');
 
   /* Keep reading lines as long as iter < nSims and we have not reached 
      the end of the file.
@@ -402,12 +399,8 @@ void ReadAndSimulate (PANALYSIS panal, long nSetParms,
         panal->mc.rgpMCVar[j]->dVal = pdTheta[j];
     }
 
-    /* Throw away remainder of line. This allows a MC output file to be used
-       directly as a restart file. */
-    if (!fscanf (pfileRestart, "%*[^\n]")) 
-      ReportError (NULL, RE_READERROR | RE_FATAL, panal->gd.szGrestart, NULL);
-    else
-      getc(pfileRestart);
+    /* Throw away remainder of line */
+    do { c = getc(pfileRestart); } while (c != '\n');
 
     /* For all experiments, compute the predictions for the parameter vector */
     Estimate_y (panal, pdTheta, pdY[iter]);
