@@ -301,16 +301,17 @@ BOOL ReadSetPoints (PMONTECARLO pMC, double rgParms[])
   if (!rgParms)
     rgParms = pMC->rgdParms; /* Put data in the usual place */
 
-   /* Throw away dummy field */
-  if (!fscanf(pMC->pfileSetPoints, "%*s")) {
-    ReportError (NULL, RE_READERROR | RE_FATAL, pMC->szSetPointsFilename, NULL);
-  }
+  /* Throw away dummy field */
+  do { 
+    c = getc(pMC->pfileSetPoints);
+    if (feof(pMC->pfileSetPoints))
+      goto Exit_ReadSetPoints;
+  } while ((c != '\t') && (c != ' '));
 
   /* Increment across set point parms list */
   for (i = 0; i < pMC->nSetParms; i++) {
 
     /* Try to read one data point */
-
     if (feof(pMC->pfileSetPoints) ||
         (fscanf(pMC->pfileSetPoints, "%lg", &pMC->rgpMCVar[i]->dVal) == EOF)) {
 
@@ -319,8 +320,8 @@ BOOL ReadSetPoints (PMONTECARLO pMC, double rgParms[])
                      pMC->szSetPointsFilename, NULL);
 
       /* If !nRuns, flag that EOF reached without issuing error */
-
       goto Exit_ReadSetPoints;
+
     } /* if */
 
     rgParms[i] = pMC->rgpMCVar[i]->dVal; /* Copy value to user array */
